pub struct handleSignedEnvelopeCall {
pub envelope: <Envelope as SolType>::RustType,
pub signatureData: <SignatureData as SolType>::RustType,
}Expand description
Function with signature handleSignedEnvelope((bytes20,bytes12,bytes),(address[],bytes[],uint32)) and selector 0xf969ff33.
function handleSignedEnvelope(Envelope memory envelope, SignatureData memory signatureData) external;Fields
envelope: <Envelope as SolType>::RustTypesignatureData: <SignatureData as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for handleSignedEnvelopeCall
impl Clone for handleSignedEnvelopeCall
Sourcefn clone(&self) -> handleSignedEnvelopeCall
fn clone(&self) -> handleSignedEnvelopeCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for handleSignedEnvelopeCall
impl Debug for handleSignedEnvelopeCall
Sourceimpl<'de> Deserialize<'de> for handleSignedEnvelopeCall
impl<'de> Deserialize<'de> for handleSignedEnvelopeCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for handleSignedEnvelopeCall
Sourceimpl PartialEq for handleSignedEnvelopeCall
impl PartialEq for handleSignedEnvelopeCall
Sourcefn eq(&self, other: &handleSignedEnvelopeCall) -> bool
fn eq(&self, other: &handleSignedEnvelopeCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for handleSignedEnvelopeCall
impl Serialize for handleSignedEnvelopeCall
Sourceimpl SolCall for handleSignedEnvelopeCall
impl SolCall for handleSignedEnvelopeCall
Sourceconst SIGNATURE: &'static str = "handleSignedEnvelope((bytes20,bytes12,bytes),(address[],bytes[],uint32))"
const SIGNATURE: &'static str = "handleSignedEnvelope((bytes20,bytes12,bytes),(address[],bytes[],uint32))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Envelope, SignatureData)
type Parameters<'a> = (Envelope, SignatureData)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<handleSignedEnvelopeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<handleSignedEnvelopeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = handleSignedEnvelopeReturn
type Return = handleSignedEnvelopeReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<handleSignedEnvelopeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<handleSignedEnvelopeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for handleSignedEnvelopeCall