pub enum ComponentSource {
Download {
uri: UriString,
digest: ComponentDigest,
},
Registry {
registry: Registry,
},
Digest(ComponentDigest),
}Variants
Download
The wasm bytecode provided at fixed url, digest provided to ensure no tampering
Registry
The wasm bytecode downloaded from a standard registry, digest provided to ensure no tampering
Digest(ComponentDigest)
An already deployed component
Implementations
Sourceimpl ComponentSource
impl ComponentSource
pub fn digest(&self) -> &ComponentDigest