pub enum Trigger {
CosmosContractEvent {
address: CosmosAddr,
chain: ChainKey,
event_type: String,
},
EvmContractEvent {
address: Address,
chain: ChainKey,
event_hash: ByteArray<32>,
},
BlockInterval {
chain: ChainKey,
n_blocks: NonZeroU32,
start_block: Option<NonZeroU64>,
end_block: Option<NonZeroU64>,
},
Cron {
schedule: String,
start_time: Option<Timestamp>,
end_time: Option<Timestamp>,
},
AtProtoEvent {
collection: String,
repo_did: Option<String>,
action: Option<AtProtoAction>,
},
HypercoreAppend {
feed_key: String,
},
Manual,
}Variants
CosmosContractEvent
EvmContractEvent
BlockInterval
Fields

n_blocks: NonZeroU32Number of blocks to wait between each execution

start_block: Option<NonZeroU64>Optional start block height indicating when the interval begins.

end_block: Option<NonZeroU64>Optional end block height indicating when the interval begins.
Cron
Fields
AtProtoEvent
ATProto Jetstream event trigger
Fields

collection: StringCollection NSID to filter for (e.g., “app.bsky.feed.post”) Supports wildcards with prefix matching (e.g., “app.bsky.feed.*”)

repo_did: Option<String>Optional DID to filter for specific repositories If None, will match events from any repository

action: Option<AtProtoAction>Action type to filter for (create, update, delete) If None, will match all action types
HypercoreAppend
Hypercore append event trigger
Manual
Implementations
Sourceimpl Trigger
impl Trigger
pub fn cosmos_contract_event( address: CosmosAddr, chain: impl TryInto<ChainKey, Error = ChainKeyError>, event_type: impl ToString, ) -> Self
pub fn evm_contract_event( address: Address, chain: impl TryInto<ChainKey, Error = ChainKeyError>, event_hash: ByteArray<32>, ) -> Self