TriggerData

Enum TriggerData 

pub enum TriggerData {
    CosmosContractEvent {
        contract_address: CosmosAddr,
        chain: ChainKey,
        event: Event,
        block_height: u64,
        event_index: u64,
    },
    EvmContractEvent {
        chain: ChainKey,
        contract_address: Address,
        log_data: LogData,
        tx_hash: TxHash,
        block_number: u64,
        log_index: u64,
        block_hash: B256,
        block_timestamp: Option<u64>,
        tx_index: u64,
    },
    BlockInterval {
        chain: ChainKey,
        block_height: u64,
    },
    Cron {
        trigger_time: Timestamp,
    },
    AtProtoEvent {
        sequence: i64,
        timestamp: i64,
        repo: String,
        collection: String,
        rkey: String,
        action: AtProtoAction,
        cid: Option<String>,
        record: Option<Value>,
        rev: Option<String>,
        op_index: Option<u32>,
    },
    HypercoreAppend {
        feed_key: String,
        index: u64,
        data: Vec<u8>,
    },
    Raw(Vec<u8>),
}
The data that came from the trigger and is passed to the component after being converted into the WIT-friendly type

Variants



CosmosContractEvent

Fields

contract_address: CosmosAddr

The address of the contract that emitted the event

chain: ChainKey

The chain where the event was emitted

event: Event

The data that was emitted by the contract

block_height: u64

The block height where the event was emitted

event_index: u64

The index of the event in this block, required for unique identification



EvmContractEvent

Fields

chain: ChainKey

The chain where the event was emitted

contract_address: Address

The address of the contract that emitted the event

log_data: LogData

The log data

tx_hash: TxHash

The transaction hash where the event was emitted

block_number: u64

The block height where the event was emitted

log_index: u64

The index of the log in the block

block_hash: B256

Hash of the block the transaction that emitted this log was mined in

block_timestamp: Option<u64>

The timestamp of the block containing this event, as proposed in https://github.com/ethereum/execution-apis/issues/295 This field is optional since nodes are not required to include it in event logs. If not provided, applications may need to fetch the block header directly to obtain the timestamp.

tx_index: u64

Index of the Transaction in the block



BlockInterval

Fields

chain: ChainKey

The chain where the blocks are checked

block_height: u64

The block height where the event was emitted



Cron

Fields

trigger_time: Timestamp

The trigger time



AtProtoEvent

ATProto Jetstream event data

Fields

sequence: i64

Sequence number of the event in the stream

timestamp: i64

Timestamp in microseconds

repo: String

Repository DID that generated the event

collection: String

Collection NSID (e.g., “app.bsky.feed.post”)

rkey: String

Record key within the collection

action: AtProtoAction

Action type (create, update, delete)

cid: Option<String>

CID of the record (None for delete events)

record: Option<Value>

Record data as JSON (None for delete events)

rev: Option<String>

Repository revision identifier for this commit (if provided by the event)

op_index: Option<u32>

Index of the operation within the commit (0-based)



HypercoreAppend

Fields

feed_key: String

Hypercore feed key that emitted the append

index: u64

Index of the appended entry

data: Vec<u8>

Raw entry data



Raw(Vec<u8>)

Implementations

Source

impl TriggerData

pub fn new_raw(data: impl AsRef<[u8]>) -> Self

pub fn trigger_type(&self) -> &str

pub fn chain(&self) -> Option<&ChainKey>