pub struct ChainConfigs {
pub cosmos: BTreeMap<ChainKeyId, CosmosChainConfigBuilder>,
pub evm: BTreeMap<ChainKeyId, EvmChainConfigBuilder>,
pub dev: BTreeMap<ChainKeyId, AnyChainConfig>,
}Expand description
Chains are identified by ChainKey, which is a combination of a namespace and id
for now - we natively support 3 namespaces: cosmos, evm, and dev
Fields
cosmos: BTreeMap<ChainKeyId, CosmosChainConfigBuilder>Cosmos-style chains (including Layer-SDK)
evm: BTreeMap<ChainKeyId, EvmChainConfigBuilder>EVM-style chains
dev: BTreeMap<ChainKeyId, AnyChainConfig>DEV-only chains The key here can be different than the chain_id inside the config
Implementations
Sourceimpl ChainConfigs
impl ChainConfigs
pub fn get_chain(&self, key: &ChainKey) -> Option<AnyChainConfig>
pub fn cosmos_iter(&self) -> impl Iterator<Item = CosmosChainConfig> + '_
pub fn evm_iter(&self) -> impl Iterator<Item = EvmChainConfig> + '_
pub fn dev_iter(&self) -> impl Iterator<Item = AnyChainConfig> + '_
pub fn all_chain_keys(&self) -> Result<Vec<ChainKey>, Error>
pub fn chain_keys(&self, namespace: ChainKeyNamespace) -> Vec<ChainKey>
pub fn add_chain( &mut self, key: ChainKey, config: AnyChainConfig, ) -> Result<(), ChainConfigError>