pub struct ChainKey {
pub namespace: ChainKeyNamespace,
pub id: ChainKeyId,
}Expand description
A ChainKey represents a blockchain network identifier, consisting of a namespace and a chain id.
The namespace indicates the type of blockchain (e.g., “ethereum”, “bitcoin”),
while the id specifies the particular network within that namespace (e.g., “1”, “cosmoshub”).
Mostly follows the specification at https://chainagnostic.org/CAIPs/caip-2 but allows the namespace part to 1 to 32 characters instead of 3 to 8 and changes the naming of chain_id -> chain_key, reference -> chain_id
Fields
namespace: ChainKeyNamespaceid: ChainKeyIdImplementations