pub struct Component {
pub source: ComponentSource,
pub permissions: Permissions,
pub fuel_limit: Option<u64>,
pub time_limit_seconds: Option<u64>,
pub config: BTreeMap<String, String>,
pub env_keys: BTreeSet<String>,
}Fields
source: ComponentSourcepermissions: Permissionsfuel_limit: Option<u64>The maximum amount of compute metering to allow for a single component execution
If not supplied, will be Workflow::DEFAULT_FUEL_LIMIT
time_limit_seconds: Option<u64>The maximum amount of time to allow for a single component execution, in seconds
If not supplied, default will be Workflow::DEFAULT_TIME_LIMIT_SECONDS
config: BTreeMap<String, String>Key-value pairs that are accessible in the components via host bindings.
env_keys: BTreeSet<String>External env variable keys to be read from the system host on execute (i.e. API keys).
Must be prefixed with WAVS_ENV_.
Implementations