pub struct CosmosSubmitAction {
pub chain: ChainKey,
pub address: CosmosAddr,
pub gas_price: Option<u128>,
}Fields
chain: ChainKeyaddress: CosmosAddrgas_price: Option<u128>Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for CosmosSubmitAction
impl<'__de, __Context> BorrowDecode<'__de, __Context> for CosmosSubmitAction
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for CosmosSubmitAction
impl Clone for CosmosSubmitAction
Sourcefn clone(&self) -> CosmosSubmitAction
fn clone(&self) -> CosmosSubmitAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CosmosSubmitAction
impl ComposeSchema for CosmosSubmitAction
Sourceimpl Debug for CosmosSubmitAction
impl Debug for CosmosSubmitAction
Sourceimpl<__Context> Decode<__Context> for CosmosSubmitAction
impl<__Context> Decode<__Context> for CosmosSubmitAction
Sourceimpl<'de> Deserialize<'de> for CosmosSubmitAction
impl<'de> Deserialize<'de> for CosmosSubmitAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for CosmosSubmitAction
impl Encode for CosmosSubmitAction
impl Eq for CosmosSubmitAction
Sourceimpl Hash for CosmosSubmitAction
impl Hash for CosmosSubmitAction
Sourceimpl Ord for CosmosSubmitAction
impl Ord for CosmosSubmitAction
Sourcefn cmp(&self, other: &CosmosSubmitAction) -> Ordering
fn cmp(&self, other: &CosmosSubmitAction) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CosmosSubmitAction
impl PartialEq for CosmosSubmitAction
Sourcefn eq(&self, other: &CosmosSubmitAction) -> bool
fn eq(&self, other: &CosmosSubmitAction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for CosmosSubmitAction
impl PartialOrd for CosmosSubmitAction
Sourceimpl Serialize for CosmosSubmitAction
impl Serialize for CosmosSubmitAction
impl StructuralPartialEq for CosmosSubmitAction