pub enum TriggerData {
CosmosContractEvent {
contract_address: CosmosAddr,
chain: ChainKey,
event: Event,
block_height: u64,
event_index: u64,
},
EvmContractEvent {
chain: ChainKey,
contract_address: Address,
log_data: LogData,
tx_hash: TxHash,
block_number: u64,
log_index: u64,
block_hash: B256,
block_timestamp: Option<u64>,
tx_index: u64,
},
BlockInterval {
chain: ChainKey,
block_height: u64,
},
Cron {
trigger_time: Timestamp,
},
AtProtoEvent {
sequence: i64,
timestamp: i64,
repo: String,
collection: String,
rkey: String,
action: AtProtoAction,
cid: Option<String>,
record: Option<Value>,
rev: Option<String>,
op_index: Option<u32>,
},
HypercoreAppend {
feed_key: String,
index: u64,
data: Vec<u8>,
},
Raw(Vec<u8>),
}Expand description
The data that came from the trigger and is passed to the component after being converted into the WIT-friendly type
Variants
CosmosContractEvent
Fields

contract_address: CosmosAddrThe address of the contract that emitted the event
EvmContractEvent
Fields

block_timestamp: Option<u64>The timestamp of the block containing this event, as proposed in https://github.com/ethereum/execution-apis/issues/295 This field is optional since nodes are not required to include it in event logs. If not provided, applications may need to fetch the block header directly to obtain the timestamp.
BlockInterval
Fields
Cron
AtProtoEvent
ATProto Jetstream event data
Fields

action: AtProtoActionAction type (create, update, delete)
HypercoreAppend
Fields
Raw(Vec<u8>)
Implementations